@@ -87,7 +87,7 @@ def load_into_bigquery(input: pd.core.frame.DataFrame, table: str, bigquery_clie
         job_config.schema = schema
     job_config.ignore_unknown_values = True
     job_config.schema_update_options = 'ALLOW_FIELD_RELAXATION'
-    job_config.max_bad_records = 10
+    job_config.max_bad_records = 1
     job_config.write_disposition = bigquery.WriteDisposition.WRITE_APPEND
     job = bigquery_client.load_table_from_dataframe(input,
                                                     table,
@@ -251,6 +251,15 @@ def upload_blob(bucket_name:str, source_file_name:str, destination_blob_name:str
     return("File {} uploaded to {}.".format(source_file_name, destination_blob_name))
 
 
+def delete_storage_date(bucket_name: str, file_list: list, storage_client: storage.Client):
+
+    source_bucket = storage_client.bucket(bucket_name)
+
+    for file in file_list:
+        file.delete()
+
+    return print(f"All file in bucket {bucket_name} deleted.")
+
 def access_secret(project_id,secret_id, version_id="latest"):
     """
     Accesses the secret version identified by secret_id and version_id.
@@ -286,3 +295,19 @@ def secret_hash(secret_value):
         
   """
   return hashlib.sha224(bytes(secret_value, "utf-8")).hexdigest()
+
+
+def value_def(value):
+
+    """
+    Função para verificar se o campo é null ou ''
+    Args:
+        value: campo a ser verificado
+    Returns:
+        value: retorna None para campo null ou '' 
+        e o campo original caso contrário
+    """
+    if value == 'null' or value == "":
+        return None
+    else:
+        return value
\ No newline at end of file
